@@ -6,5 +6,5 @@ from . import views
 
 app_name = 'discordbot'
 urlpatterns = [
-    path('amongus/tracker/<id>/post', views.amongus_tracker_post, name="amongus-tracker-post"),
+    path('amongus/tracker/post', views.amongus_tracker_post, name="amongus-tracker-post"),
 ]
